@@ -9,13 +9,15 @@
 #include "mat.h"
 #include "nutil.h"
 
+using namespace std;
+
 bool Conslink(long nsam, double **DPtr, double **dend);
 bool ConISS(long nsam, double **DPtr, double **dend);
 bool CalcDissimilarity(dMat &Data, double ***DissimPtr, int coef);
 
 extern "C" {
  /* __declspec(dllexport) */
-SEXP chclust(SEXP sexpData, SEXP sexMethod)
+SEXP chclust_c(SEXP sexpData, SEXP sexMethod)
 {
    SEXP dims, eMessage = R_NilValue;
    dims = Rf_getAttrib(sexpData, R_DimSymbol);
